"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.passwordValid = exports.collectionSlugValid = exports.packageSlugValid = exports.catalogSlugValid = exports.usernameValid = void 0;
function usernameValid(username) {
    const regex = /^[a-z\d](?:[a-z\d]|-(?=[a-z\d])){0,38}$/;
    if (username === undefined) {
        return "USERNAME_REQUIRED";
    }
    if (username.length === 0) {
        return "USERNAME_REQUIRED";
    }
    if (username.length > 39) {
        return "USERNAME_TOO_LONG";
    }
    if (username.toLowerCase().match(regex) == null) {
        return "INVALID_CHARACTERS";
    }
    return true;
}
exports.usernameValid = usernameValid;
function catalogSlugValid(slug) {
    if (slug === undefined)
        return `CATALOG_SLUG_REQUIRED`;
    if (slug.length === 0)
        return `CATALOG_SLUG_REQUIRED`;
    if (slug.length > 38)
        return `CATALOG_SLUG_TOO_LONG`;
    const regExp = /^[a-z\d](?:[a-z\d]|-(?=[a-z\d])){0,38}$/i;
    if (!slug.match(regExp))
        return `CATALOG_SLUG_INVALID`;
    return true;
}
exports.catalogSlugValid = catalogSlugValid;
function packageSlugValid(slug) {
    if (slug === undefined)
        return `PACKAGE_SLUG_REQUIRED`;
    if (slug.length === 0)
        return `PACKAGE_SLUG_REQUIRED`;
    if (slug.length > 38)
        return `PACKAGE_SLUG_TOO_LONG`;
    const regExp = /^[a-z0-9]+(?:(?:(?:[._]|__|[-]*)[a-z0-9]+)+)?$/;
    if (!slug.match(regExp))
        return "PACKAGE_SLUG_INVALID";
    return true;
}
exports.packageSlugValid = packageSlugValid;
function collectionSlugValid(slug) {
    if (slug === undefined)
        return `COLLECTION_SLUG_REQUIRED`;
    if (slug.length === 0)
        return `COLLECTION_SLUG_REQUIRED`;
    if (slug.length > 100)
        return `COLLECTION_SLUG_TOO_LONG`;
    const regExp = /^[a-z\d](?:[a-z\d]|-(?=[a-z\d])){0,38}$/i;
    if (!slug.match(regExp))
        return `COLLECTION_SLUG_INVALID`;
    return true;
}
exports.collectionSlugValid = collectionSlugValid;
function passwordValid(password) {
    const regex = /[0-9@#$%!]/;
    if (password === undefined || password.length === 0) {
        return "PASSWORD_REQUIRED";
    }
    if (password.length > 99) {
        return "PASSWORD_TOO_LONG";
    }
    if (password.length < 8) {
        return "PASSWORD_TOO_SHORT";
    }
    if (password.length < 16 && password.match(regex) == null) {
        return "INVALID_CHARACTERS";
    }
    return true;
}
exports.passwordValid = passwordValid;
//# sourceMappingURL=Validators.js.map